nvector.objects.ECEFvector — nvector 0.7.5 documentation

# nvector.objects.ECEFvector

class `ECEFvector`(pvector, frame=None, scalar=None)

  > Geographical position given as Cartesian position vector in frame E

  Parameters
    pvector: 3 x n array

      > Cartesian position vector(s) [m] from E to B, decomposed in E.

      frame: FrameE object

        reference ellipsoid. The default ellipsoid model used is WGS84, but other ellipsoids/spheres might be specified.

  Notes

  The position of B (typically body) relative to E (typically Earth) is given into this function as p-vector, p_EB_E relative to the center of the frame.

  `__init__`(self, pvector, frame=None, scalar=None)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `__init__`(self, pvector[, frame, scalar]) | Initialize self.
  `change_frame`(self, frame) | Converts to Cartesian position vector in another frame
  `delta_to`(self, other) | Returns cartesian delta vector from positions a to b decomposed in N.
  `to_ecef_vector`(self) | Returns position as ECEFvector object.
  `to_geo_point`(self) | Returns position as GeoPoint object.
  `to_nvector`(self) | Returns position as Nvector object.

  Attributes

  `azimuth` | Azimuth in radian
  `azimuth_deg` | Azimuth in degree.
  `elevation` | Elevation in radian.
  `elevation_deg` | Elevation in degree.
  `length` | Length of the pvector.